==> bw-webdav-4.0.7-sources.jar: org/bedework/webdav/servlet/shared/WdCollectionBase.java <==
/* ********************************************************************
    Licensed to Jasig under one or more contributor license
    agreements. See the NOTICE file distributed with this work
    for additional information regarding copyright ownership.
    Jasig licenses this file to you under the Apache License,
    Version 2.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a
    copy of the License at:

    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on
    an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied. See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.bedework.webdav.servlet.shared;

/** Class to represent a collection in WebDAV
 *
 * @author douglm
 *
 * @param <T>
 */
public abstract class WdCollectionBase <T> extends WdCollection<T> {
  /** Constructor
   *
   * @throws WebdavException
   */
  public WdCollectionBase() throws WebdavException {
    super();
  }

  /* ====================================================================
   *                      Abstract method implementations
   * ==================================================================== */

  @Override
  public boolean isAlias() {
    return false;
  }

  @Override
  public String getAliasUri() throws WebdavException {
    return null;
  }
}

==> bw-webdav-4.0.11-sources.jar: org/bedework/webdav/servlet/shared/WdCollectionBase.java <==
/* ********************************************************************
    Licensed to Jasig under one or more contributor license
    agreements. See the NOTICE file distributed with this work
    for additional information regarding copyright ownership.
    Jasig licenses this file to you under the Apache License,
    Version 2.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a
    copy of the License at:

    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on
    an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied. See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.bedework.webdav.servlet.shared;

/** Class to represent a collection in WebDAV
 *
 * @author douglm
 *
 * @param <T>
 */
public abstract class WdCollectionBase <T> extends WdCollection<T> {
  /** Constructor
   *
   * @throws WebdavException
   */
  public WdCollectionBase() throws WebdavException {
    super();
  }

  /* ====================================================================
   *                      Abstract method implementations
   * ==================================================================== */

  @Override
  public boolean isAlias() {
    return false;
  }

  @Override
  public String getAliasUri() {
    return null;
  }
}
